@@ -1,6 +1,27 @@
 #!/usr/bin/python3
 
-"""Split up a file and yield its pieces based on some line terminator."""
+r"""
+Split up a file and yield its pieces based on some line terminator.
+
+Usage looks like:
+    $ /usr/local/cpython-3.6/bin/python3
+    Python 3.6.0 (default, Apr 22 2017, 09:17:19)
+    [GCC 5.4.0 20160609] on linux
+    Type "help", "copyright", "credits" or "license" for more information.
+    >>> import readline0
+    >>> file_ = open('/etc/shells', 'r')
+    >>> for line in readline0.readline0(file_=file_, separator=b'\n'):
+    ...     print(line)
+    ...
+    b'# /etc/shells: valid login shells'
+    b'/bin/sh'
+    b'/bin/dash'
+    b'/bin/bash'
+    b'/bin/rbash'
+    >>>
+
+Of course separator need not be a newline; it defaults to a null byte.
+"""
 
 # This software is the proprietary property of The Regents of the University of California ("The Regents") Copyright (c)
 # 1993-2006 The Regents of the University of California, Irvine campus. All Rights Reserved.
@@ -35,7 +56,11 @@ import sys
 def readline0(file_=sys.stdin, separator=b'\0', blocksize=2 ** 16):
     # pylint: disable=W1401
     # W1401: We really do want a null byte
-    """Instantiate Readline0 class and yield what we get back."""
+    """
+    Instantiate Readline0 class and yield what we get back.
+
+    file_ defaults to sys.stdin, separator defaults to a null, and blocksize defaults to 64K.
+    """
     if hasattr(file_, 'buffer'):
         # Do bytes I/O
         file_ = getattr(file_, 'buffer')
